# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- Nothing yet

## [0.0.0]

- No features yet

[Unreleased]: https://github.com/blakeNaccarato/stronger/compare/0.0.0...HEAD
[0.0.0]: https://github.com/blakeNaccarato/stronger/releases/tag/0.0.0
